@@ -7,9 +7,14 @@ Defining and manipulating binaries embedding Python.
 */
 
 use {
-    super::{config::PyembedPythonInterpreterConfig, distribution::AppleSdkInfo},
-    crate::environment::Environment,
+    crate::{
+        environment::Environment,
+        py_packaging::{config::PyembedPythonInterpreterConfig, distribution::AppleSdkInfo},
+    },
     anyhow::{anyhow, Context, Result},
+    pyo3_build_config::{
+        BuildFlags, InterpreterConfig as PyO3InterpreterConfig, PythonImplementation, PythonVersion,
+    },
     python_packaging::{
         policy::PythonPackagingPolicy,
         resource::{
@@ -17,13 +22,12 @@ use {
             PythonPackageResource, PythonResource,
         },
         resource_collection::{
-            CompiledResourcesCollection, PrePackagedResource, PythonResourceAddCollectionContext,
+            AddResourceAction, CompiledResourcesCollection, PrePackagedResource,
+            PythonResourceAddCollectionContext,
         },
     },
     std::{
         collections::HashMap,
-        convert::TryFrom,
-        io::Write,
         path::{Path, PathBuf},
         sync::Arc,
     },
@@ -148,6 +152,42 @@ impl TryFrom<&str> for WindowsRuntimeDllsMode {
     }
 }
 
+/// Describes extra behavior for a linker invocation.
+#[derive(Clone, Debug, PartialEq)]
+pub enum LinkingAnnotation {
+    /// Link an Apple framework library of the given name.
+    LinkFramework(String),
+
+    /// Link a library of the given name.
+    LinkLibrary(String),
+
+    /// Link a static library of the given name.
+    LinkLibraryStatic(String),
+
+    /// A search path for libraries.
+    Search(PathBuf),
+
+    /// A search path for native libraries.
+    SearchNative(PathBuf),
+}
+
+impl LinkingAnnotation {
+    /// Convert the instance to a `cargo:*` string representing this annotation.
+    pub fn to_cargo_annotation(&self) -> String {
+        match self {
+            Self::LinkFramework(framework) => {
+                format!("cargo:rustc-link-lib=framework={}", framework)
+            }
+            Self::LinkLibrary(lib) => format!("cargo:rustc-link-lib={}", lib),
+            Self::LinkLibraryStatic(lib) => format!("cargo:rustc-link-lib=static={}", lib),
+            Self::Search(path) => format!("cargo:rustc-link-search={}", path.display()),
+            Self::SearchNative(path) => {
+                format!("cargo:rustc-link-search=native={}", path.display())
+            }
+        }
+    }
+}
+
 /// A callable that can influence PythonResourceAddCollectionContext.
 pub type ResourceAddCollectionContextCallback<'a> = Box<
     dyn Fn(
@@ -321,7 +361,7 @@ pub trait PythonBinaryBuilder {
     fn add_distribution_resources(
         &mut self,
         callback: Option<ResourceAddCollectionContextCallback>,
-    ) -> Result<()>;
+    ) -> Result<Vec<AddResourceAction>>;
 
     /// Add a `PythonModuleSource` to the resources collection.
     ///
@@ -332,7 +372,7 @@ pub trait PythonBinaryBuilder {
         &mut self,
         module: &PythonModuleSource,
         add_context: Option<PythonResourceAddCollectionContext>,
-    ) -> Result<()>;
+    ) -> Result<Vec<AddResourceAction>>;
 
     /// Add a `PythonPackageResource` to the resources collection.
     ///
@@ -343,7 +383,7 @@ pub trait PythonBinaryBuilder {
         &mut self,
         resource: &PythonPackageResource,
         add_context: Option<PythonResourceAddCollectionContext>,
-    ) -> Result<()>;
+    ) -> Result<Vec<AddResourceAction>>;
 
     /// Add a `PythonPackageDistributionResource` to the resources collection.
     ///
@@ -354,7 +394,7 @@ pub trait PythonBinaryBuilder {
         &mut self,
         resource: &PythonPackageDistributionResource,
         add_context: Option<PythonResourceAddCollectionContext>,
-    ) -> Result<()>;
+    ) -> Result<Vec<AddResourceAction>>;
 
     /// Add a `PythonExtensionModule` to make available.
     ///
@@ -368,14 +408,14 @@ pub trait PythonBinaryBuilder {
         &mut self,
         extension_module: &PythonExtensionModule,
         add_context: Option<PythonResourceAddCollectionContext>,
-    ) -> Result<()>;
+    ) -> Result<Vec<AddResourceAction>>;
 
     /// Add a `File` to the resource collection.
     fn add_file_data(
         &mut self,
         file: &File,
         add_context: Option<PythonResourceAddCollectionContext>,
-    ) -> Result<()>;
+    ) -> Result<Vec<AddResourceAction>>;
 
     /// Filter embedded resources against names in files.
     ///
@@ -407,36 +447,186 @@ pub trait PythonBinaryBuilder {
     ) -> Result<EmbeddedPythonContext>;
 }
 
-/// Describes how to link a binary against Python.
-pub struct PythonLinkingInfo {
-    /// Path to a `pythonXY` library to link against.
-    pub libpythonxy_filename: PathBuf,
+/// Represents a linkable target defining a Python implementation.
+pub trait LinkablePython {
+    /// Write any files that need to exist to support linking.
+    ///
+    /// Files will be written to the directory specified.
+    fn write_files(&self, dest_dir: &Path, target_triple: &str) -> Result<()>;
 
-    /// The contents of `libpythonxy_filename`.
-    pub libpythonxy_data: Vec<u8>,
-
-    /// Path to an existing `libpython` to link against. If present, this is
-    /// the actual library containing Python symbols and `libpythonXY` is
-    /// a placeholder.
-    pub libpython_filename: Option<PathBuf>,
-
-    /// Path to a library containing an alternate `config.c`.
-    pub libpyembeddedconfig_filename: Option<PathBuf>,
-
-    /// The contents of `libpyembeddedconfig_filename`.
-    pub libpyembeddedconfig_data: Option<Vec<u8>>,
-
-    /// Lines that need to be emitted from a Cargo build script.
-    pub cargo_metadata: Vec<String>,
+    /// Obtain linker annotations needed to link this libpython.
+    ///
+    /// `dest_dir` will be the directory where any files written by `write_files()` will
+    /// be located.
+    ///
+    /// `alias` denotes whether to alias the library name to `pythonXY`.
+    fn linking_annotations(&self, dest_dir: &Path, alias: bool) -> Result<Vec<LinkingAnnotation>>;
 }
 
+/// Link against a shared library on the filesystem.
+#[derive(Clone, Debug)]
+pub struct LinkSharedLibraryPath {
+    /// Path to dynamic library to link.
+    pub library_path: PathBuf,
+
+    /// Additional linking annotations.
+    pub linking_annotations: Vec<LinkingAnnotation>,
+}
+
+impl LinkSharedLibraryPath {
+    /// Resolve the name of the library.
+    fn library_name(&self) -> Result<String> {
+        let filename = self
+            .library_path
+            .file_name()
+            .ok_or_else(|| anyhow!("unable to resolve shared library file name"))?
+            .to_string_lossy();
+
+        if filename.ends_with(".dll") {
+            Ok(filename.trim_end_matches(".dll").to_string())
+        } else if filename.ends_with(".dylib") {
+            Ok(filename
+                .trim_end_matches(".dylib")
+                .trim_start_matches("lib")
+                .to_string())
+        } else if filename.ends_with(".so") {
+            Ok(filename
+                .trim_end_matches(".so")
+                .trim_start_matches("lib")
+                .to_string())
+        } else {
+            Err(anyhow!(
+                "unhandled libpython shared library filename: {}",
+                filename
+            ))
+        }
+    }
+}
+
+impl LinkablePython for LinkSharedLibraryPath {
+    fn write_files(&self, _dest_dir: &Path, _target_triple: &str) -> Result<()> {
+        Ok(())
+    }
+
+    fn linking_annotations(&self, _dest_dir: &Path, alias: bool) -> Result<Vec<LinkingAnnotation>> {
+        let lib_dir = self
+            .library_path
+            .parent()
+            .ok_or_else(|| anyhow!("could not derive parent directory of library path"))?;
+
+        let mut annotations = vec![
+            LinkingAnnotation::LinkLibrary(if alias {
+                format!("pythonXY:{}", self.library_name()?)
+            } else {
+                self.library_name()?
+            }),
+            LinkingAnnotation::SearchNative(lib_dir.to_path_buf()),
+        ];
+
+        annotations.extend(self.linking_annotations.iter().cloned());
+
+        Ok(annotations)
+    }
+}
+
+/// Link against a custom built static library with tracked library data.
+#[derive(Clone, Debug)]
+pub struct LinkStaticLibraryData {
+    /// libpython static library content.
+    pub library_data: Vec<u8>,
+
+    /// Additional linker directives to link this static library.
+    pub linking_annotations: Vec<LinkingAnnotation>,
+}
+
+impl LinkStaticLibraryData {
+    fn library_name(&self) -> &'static str {
+        "python3"
+    }
+
+    fn library_path(&self, dest_dir: impl AsRef<Path>, target_triple: &str) -> PathBuf {
+        dest_dir
+            .as_ref()
+            .join(if target_triple.contains("-windows-") {
+                format!("{}.lib", self.library_name())
+            } else {
+                format!("lib{}.a", self.library_name())
+            })
+    }
+}
+
+impl LinkablePython for LinkStaticLibraryData {
+    fn write_files(&self, dest_dir: &Path, target_triple: &str) -> Result<()> {
+        let lib_path = self.library_path(dest_dir, target_triple);
+
+        std::fs::write(&lib_path, &self.library_data)
+            .with_context(|| format!("writing {}", lib_path.display()))?;
+
+        Ok(())
+    }
+
+    fn linking_annotations(&self, dest_dir: &Path, alias: bool) -> Result<Vec<LinkingAnnotation>> {
+        let mut annotations = vec![
+            LinkingAnnotation::LinkLibraryStatic(if alias {
+                format!("pythonXY:{}", self.library_name())
+            } else {
+                self.library_name().to_string()
+            }),
+            LinkingAnnotation::SearchNative(dest_dir.to_path_buf()),
+        ];
+
+        annotations.extend(self.linking_annotations.iter().cloned());
+
+        Ok(annotations)
+    }
+}
+
+/// Describes how to link a `libpython`.
+pub enum LibpythonLinkSettings {
+    /// Link against an existing shared library.
+    ExistingDynamic(LinkSharedLibraryPath),
+    /// Link against a custom static library.
+    StaticData(LinkStaticLibraryData),
+}
+
+impl LinkablePython for LibpythonLinkSettings {
+    fn write_files(&self, dest_dir: &Path, target_triple: &str) -> Result<()> {
+        match self {
+            Self::ExistingDynamic(l) => l.write_files(dest_dir, target_triple),
+            Self::StaticData(l) => l.write_files(dest_dir, target_triple),
+        }
+    }
+
+    fn linking_annotations(&self, dest_dir: &Path, alias: bool) -> Result<Vec<LinkingAnnotation>> {
+        match self {
+            Self::ExistingDynamic(l) => l.linking_annotations(dest_dir, alias),
+            Self::StaticData(l) => l.linking_annotations(dest_dir, alias),
+        }
+    }
+}
+
+impl From<LinkSharedLibraryPath> for LibpythonLinkSettings {
+    fn from(l: LinkSharedLibraryPath) -> Self {
+        Self::ExistingDynamic(l)
+    }
+}
+
+impl From<LinkStaticLibraryData> for LibpythonLinkSettings {
+    fn from(l: LinkStaticLibraryData) -> Self {
+        Self::StaticData(l)
+    }
+}
+
+/// Filename of artifact containing the default PythonInterpreterConfig.
+pub const DEFAULT_PYTHON_CONFIG_FILENAME: &str = "default_python_config.rs";
+
 /// Holds context necessary to embed Python in a binary.
 pub struct EmbeddedPythonContext<'a> {
     /// The configuration for the embedded interpreter.
     pub config: PyembedPythonInterpreterConfig,
 
     /// Information on how to link against Python.
-    pub linking_info: PythonLinkingInfo,
+    pub link_settings: LibpythonLinkSettings,
 
     /// Python resources that need to be serialized to a file.
     pub pending_resources: Vec<(CompiledResourcesCollection<'a>, PathBuf)>,
@@ -449,58 +639,67 @@ pub struct EmbeddedPythonContext<'a> {
 
     /// Rust target triple for the target we are building for.
     pub target_triple: String,
+
+    /// Name of the Python implementation.
+    pub python_implementation: PythonImplementation,
+
+    /// Python interpreter version.
+    pub python_version: PythonVersion,
+
+    /// Path to a `python` executable that runs on the host/build machine.
+    pub python_exe_host: PathBuf,
+
+    /// Python build flags.
+    ///
+    /// To pass to PyO3.
+    pub python_build_flags: BuildFlags,
 }
 
 impl<'a> EmbeddedPythonContext<'a> {
     /// Obtain the filesystem of the generated Rust source file containing the interpreter configuration.
     pub fn interpreter_config_rs_path(&self, dest_dir: impl AsRef<Path>) -> PathBuf {
-        dest_dir.as_ref().join("default_python_config.rs")
+        dest_dir.as_ref().join(DEFAULT_PYTHON_CONFIG_FILENAME)
     }
 
-    /// Obtain path to a compiled library containing content of a compiled `config.c` file.
-    ///
-    /// This file contains global data structures for libpython defining extension modules.
-    pub fn python_config_library_path(&self, dest_dir: impl AsRef<Path>) -> Option<PathBuf> {
-        self.linking_info
-            .libpyembeddedconfig_filename
-            .as_ref()
-            .map(|filename| dest_dir.as_ref().join(filename))
+    /// Resolve the filesystem path to the PyO3 configuration file.
+    pub fn pyo3_config_path(&self, dest_dir: impl AsRef<Path>) -> PathBuf {
+        dest_dir.as_ref().join("pyo3-build-config-file.txt")
     }
 
-    /// Resolve path to library containing libpython.
-    pub fn libpython_path(&self, dest_dir: impl AsRef<Path>) -> PathBuf {
-        dest_dir
-            .as_ref()
-            .join(&self.linking_info.libpythonxy_filename)
-    }
-
-    /// Resolve the filesystem path to the file containing cargo: lines.
-    ///
-    /// The `cargo:` lines will enabling linking with the appropriate libpython.
-    pub fn cargo_metadata_path(&self, dest_dir: impl AsRef<Path>) -> PathBuf {
-        dest_dir.as_ref().join("cargo_metadata.txt")
-    }
-
-    /// Obtain lines constituting cargo metadata.
-    ///
-    /// These should be printed from a build script. The printed lines enable
-    /// linking with our libpython.
-    pub fn cargo_metadata_lines(&self, dest_dir: impl AsRef<Path>) -> Vec<String> {
-        let mut lines = self.linking_info.cargo_metadata.clone();
-
-        // Tell Cargo where libpythonXY is located.
-        lines.push(format!(
-            "cargo:rustc-link-search=native={}",
-            dest_dir.as_ref().display()
-        ));
-
-        // Give dependent crates the path to the default config file.
-        lines.push(format!(
-            "cargo:default-python-config-rs={}",
-            self.interpreter_config_rs_path(dest_dir).display()
-        ));
-
-        lines
+    /// Resolve a [PyO3InterpreterConfig] for this instance.
+    pub fn pyo3_interpreter_config(
+        &self,
+        dest_dir: impl AsRef<Path>,
+    ) -> Result<PyO3InterpreterConfig> {
+        Ok(PyO3InterpreterConfig {
+            implementation: self.python_implementation,
+            version: self.python_version,
+            // Irrelevant since we control link settings below.
+            shared: matches!(
+                &self.link_settings,
+                LibpythonLinkSettings::ExistingDynamic(_)
+            ),
+            // pyembed requires the full Python API.
+            abi3: false,
+            // We define linking info via explicit build script lines.
+            lib_name: None,
+            lib_dir: None,
+            executable: Some(self.python_exe_host.to_string_lossy().to_string()),
+            // TODO set from Python distribution metadata.
+            pointer_width: Some(if self.target_triple.starts_with("i686-") {
+                32
+            } else {
+                64
+            }),
+            build_flags: BuildFlags(self.python_build_flags.0.clone()),
+            suppress_build_script_link_lines: true,
+            extra_build_script_lines: self
+                .link_settings
+                .linking_annotations(dest_dir.as_ref(), self.target_triple.contains("-windows-"))?
+                .iter()
+                .map(|la| la.to_cargo_annotation())
+                .collect::<Vec<_>>(),
+        })
     }
 
     /// Ensure packed resources files are written.
@@ -522,18 +721,8 @@ impl<'a> EmbeddedPythonContext<'a> {
 
     /// Ensure files required by libpython are written.
     pub fn write_libpython(&self, dest_dir: impl AsRef<Path>) -> Result<()> {
-        let mut fh = std::fs::File::create(self.libpython_path(&dest_dir))?;
-        fh.write_all(&self.linking_info.libpythonxy_data)?;
-
-        if let Some(data) = &self.linking_info.libpyembeddedconfig_data {
-            let path = self.python_config_library_path(&dest_dir).ok_or_else(|| {
-                anyhow!("embedded Python config library data defined without path")
-            })?;
-            let mut fh = std::fs::File::create(&path)?;
-            fh.write_all(data)?;
-        }
-
-        Ok(())
+        self.link_settings
+            .write_files(dest_dir.as_ref(), &self.target_triple)
     }
 
     /// Write the file containing the default interpreter configuration Rust struct.
@@ -544,10 +733,14 @@ impl<'a> EmbeddedPythonContext<'a> {
         Ok(())
     }
 
-    /// Write file containing cargo metadata lines.
-    pub fn write_cargo_metadata(&self, dest_dir: impl AsRef<Path>) -> Result<()> {
-        let mut fh = std::fs::File::create(self.cargo_metadata_path(&dest_dir))?;
-        fh.write_all(self.cargo_metadata_lines(dest_dir).join("\n").as_bytes())?;
+    /// Write the PyO3 configuration file.
+    pub fn write_pyo3_config(&self, dest_dir: impl AsRef<Path>) -> Result<()> {
+        let dest_dir = dest_dir.as_ref();
+
+        let mut fh = std::fs::File::create(self.pyo3_config_path(dest_dir))?;
+        self.pyo3_interpreter_config(dest_dir)?
+            .to_writer(&mut fh)
+            .map_err(|e| anyhow!("error writing PyO3 config file: {}", e))?;
 
         Ok(())
     }
@@ -560,8 +753,8 @@ impl<'a> EmbeddedPythonContext<'a> {
             .context("write_libpython()")?;
         self.write_interpreter_config_rs(&dest_dir)
             .context("write_interpreter_config_rs()")?;
-        self.write_cargo_metadata(&dest_dir)
-            .context("write_cargo_metadata()")?;
+        self.write_pyo3_config(&dest_dir)
+            .context("write_pyo3_config()")?;
 
         Ok(())
     }
@@ -605,4 +798,36 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn test_dynamic_library_name() -> Result<()> {
+        assert_eq!(
+            LinkSharedLibraryPath {
+                library_path: "libpython3.9.so".into(),
+                linking_annotations: vec![],
+            }
+            .library_name()?,
+            "python3.9"
+        );
+
+        assert_eq!(
+            LinkSharedLibraryPath {
+                library_path: "libpython3.9.dylib".into(),
+                linking_annotations: vec![],
+            }
+            .library_name()?,
+            "python3.9"
+        );
+
+        assert_eq!(
+            LinkSharedLibraryPath {
+                library_path: "python3.dll".into(),
+                linking_annotations: vec![],
+            }
+            .library_name()?,
+            "python3"
+        );
+
+        Ok(())
+    }
 }
