@@ -36,7 +36,6 @@ use {
     slog::{info, warn},
     std::{
         collections::{hash_map::RandomState, BTreeMap, HashMap},
-        convert::TryFrom,
         io::{BufRead, BufReader, Read},
         path::{Path, PathBuf},
         sync::Arc,
@@ -485,6 +484,9 @@ pub struct StandaloneDistribution {
 
     /// List of strings denoting C Runtime requirements.
     pub crt_features: Vec<String>,
+
+    /// Configuration variables used by Python.
+    config_vars: HashMap<String, String>,
 }
 
 impl StandaloneDistribution {
@@ -522,7 +524,7 @@ impl StandaloneDistribution {
         let reader = BufReader::new(fh);
         warn!(logger, "reading data from Python distribution...");
 
-        Self::from_tar_zst(reader, &extract_dir)
+        Self::from_tar_zst(reader, extract_dir)
     }
 
     /// Extract and analyze a standalone distribution from a zstd compressed tar stream.
@@ -984,6 +986,7 @@ impl StandaloneDistribution {
             cache_tag: pi.python_implementation_cache_tag,
             module_suffixes,
             crt_features: pi.crt_features,
+            config_vars: pi.python_config_vars,
         })
     }
 
@@ -1037,7 +1040,7 @@ impl StandaloneDistribution {
 
         let python_paths = resolve_python_paths(&venv_base, &self.version);
 
-        invoke_python(&python_paths, &logger, &["-m", "ensurepip"]);
+        invoke_python(&python_paths, logger, &["-m", "ensurepip"]);
 
         prepare_hacked_distutils(logger, &self.stdlib_path.join("distutils"), &venv_base, &[])
             .unwrap();
@@ -1051,16 +1054,16 @@ impl StandaloneDistribution {
         let venv_dir_s = path.display().to_string();
 
         // This will recreate it, if it was deleted
-        let python_paths = self.create_hacked_base(&logger);
+        let python_paths = self.create_hacked_base(logger);
 
         if path.exists() {
             warn!(logger, "re-using {} {}", "venv", venv_dir_s);
         } else {
             warn!(logger, "creating {} {}", "venv", venv_dir_s);
-            invoke_python(&python_paths, &logger, &["-m", "venv", venv_dir_s.as_str()]);
+            invoke_python(&python_paths, logger, &["-m", "venv", venv_dir_s.as_str()]);
         }
 
-        resolve_python_paths(&path, &self.version)
+        resolve_python_paths(path, &self.version)
     }
 
     /// Create or re-use an existing venv
@@ -1070,7 +1073,7 @@ impl StandaloneDistribution {
         logger: &slog::Logger,
         venv_dir_path: &Path,
     ) -> Result<(PythonPaths, HashMap<String, String>)> {
-        let python_paths = self.create_venv(logger, &venv_dir_path);
+        let python_paths = self.create_venv(logger, venv_dir_path);
 
         let mut extra_envs = HashMap::new();
 
@@ -1161,7 +1164,8 @@ impl PythonDistribution for StandaloneDistribution {
     }
 
     fn python_major_minor_version(&self) -> String {
-        self.version[0..3].to_string()
+        let parts = self.version.split('.').take(2).collect::<Vec<_>>();
+        parts.join(".")
     }
 
     fn python_implementation(&self) -> &str {
@@ -1226,6 +1230,10 @@ impl PythonDistribution for StandaloneDistribution {
         Ok(self.module_suffixes.clone())
     }
 
+    fn python_config_vars(&self) -> &HashMap<String, String> {
+        &self.config_vars
+    }
+
     fn stdlib_test_packages(&self) -> Vec<String> {
         self.stdlib_test_packages.clone()
     }
@@ -1331,7 +1339,7 @@ impl PythonDistribution for StandaloneDistribution {
             PythonResource::from(PythonModuleSource {
                 name: name.clone(),
                 source: FileData::Path(path.clone()),
-                is_package: is_package_from_path(&path),
+                is_package: is_package_from_path(path),
                 cache_tag: self.cache_tag.clone(),
                 is_stdlib: true,
                 is_test: self.is_stdlib_test_package(name),
@@ -1348,7 +1356,7 @@ impl PythonDistribution for StandaloneDistribution {
                         relative_name: name.clone(),
                         data: FileData::Path(path.clone()),
                         is_stdlib: true,
-                        is_test: self.is_stdlib_test_package(&package),
+                        is_test: self.is_stdlib_test_package(package),
                     })
                 })
             })
@@ -1369,7 +1377,7 @@ impl PythonDistribution for StandaloneDistribution {
 
         if !pip_path.exists() {
             warn!(logger, "{} doesnt exist", pip_path.display().to_string());
-            invoke_python(&python_paths, &logger, &["-m", "ensurepip"]);
+            invoke_python(&python_paths, logger, &["-m", "ensurepip"]);
         }
 
         Ok(pip_path)
@@ -1455,7 +1463,7 @@ pub mod tests {
 
     #[test]
     fn test_stdlib_annotations() -> Result<()> {
-        let distribution = get_default_distribution()?;
+        let distribution = get_default_distribution(None)?;
 
         for resource in distribution.python_resources() {
             match resource {
@@ -1573,7 +1581,7 @@ pub mod tests {
 
     #[test]
     fn compile_syntax_error() -> Result<()> {
-        let dist = get_default_distribution()?;
+        let dist = get_default_distribution(None)?;
 
         let temp_dir = tempfile::TempDir::new()?;
 
