@@ -25,10 +25,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("base-x", "MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("base64", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -49,11 +45,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("bumpalo", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("byteorder", "MIT OR Unlicense")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -88,20 +79,11 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("const_fn", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("cpufeatures", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("cpython", "MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("crc32fast", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -116,10 +98,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("discard", "MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component = tugger_licensing::LicensedComponent::new_spdx("dunce", "CC0-1.0")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
@@ -157,11 +135,21 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     res.push(component);
 
     let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("itertools", "Apache-2.0 OR MIT")?;
+        tugger_licensing::LicensedComponent::new_spdx("indoc", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("itoa", "Apache-2.0 OR MIT")?;
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("indoc-impl", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
+    let mut component = tugger_licensing::LicensedComponent::new_spdx("instant", "BSD-3-Clause")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("itertools", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
@@ -188,7 +176,8 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("log", "Apache-2.0 OR MIT")?;
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("lock_api", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
@@ -216,11 +205,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("num-traits", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("once_cell", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -231,11 +215,26 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("parking_lot", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("parking_lot_core", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("paste", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("paste-impl", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("pathdiff", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -266,6 +265,31 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component = tugger_licensing::LicensedComponent::new_spdx("pyo3", "Apache-2.0")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("pyo3-build-config", "Apache-2.0")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
+    let mut component = tugger_licensing::LicensedComponent::new_spdx("pyo3-macros", "Apache-2.0")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("pyo3-macros-backend", "Apache-2.0")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
+    let mut component = tugger_licensing::LicensedComponent::new_spdx(
+        "python-oxidized-importer",
+        "MPL-2.0 OR Python-2.0",
+    )?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("python-packaging", "MPL-2.0")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -276,10 +300,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("python3-sys", "Python-2.0")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("quick-error", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -332,33 +352,18 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("rustc_version", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("rusty-fork", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("ryu", "Apache-2.0 OR BSL-1.0")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("same-file", "MIT OR Unlicense")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
     let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("semver", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("semver-parser", "Apache-2.0 OR MIT")?;
+        tugger_licensing::LicensedComponent::new_spdx("scopeguard", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
@@ -372,15 +377,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("serde_json", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("sha1", "BSD-3-Clause")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component = tugger_licensing::LicensedComponent::new_spdx("sha2", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
@@ -402,35 +398,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("standback", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("stdweb", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("stdweb-derive", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component = tugger_licensing::LicensedComponent::new_spdx(
-        "stdweb-internal-macros",
-        "Apache-2.0 OR MIT",
-    )?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component = tugger_licensing::LicensedComponent::new_spdx(
-        "stdweb-internal-runtime",
-        "Apache-2.0 OR MIT",
-    )?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component = tugger_licensing::LicensedComponent::new_spdx("syn", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
@@ -454,16 +421,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("time-macros", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("time-macros-impl", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("tugger-file-manifest", "MPL-2.0")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -484,6 +441,11 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("unindent", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("version_check", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -506,33 +468,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("wasm-bindgen", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("wasm-bindgen-backend", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("wasm-bindgen-macro", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component = tugger_licensing::LicensedComponent::new_spdx(
-        "wasm-bindgen-macro-support",
-        "Apache-2.0 OR MIT",
-    )?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("wasm-bindgen-shared", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("winapi", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
