@@ -28,7 +28,6 @@ use {
     },
     std::{
         collections::HashMap,
-        convert::TryFrom,
         path::{Path, PathBuf},
         sync::{Arc, Mutex},
     },
@@ -254,7 +253,7 @@ impl EvaluationContext {
         let file_loader_env = self.child_env.clone();
 
         starlark::eval::simple::eval(
-            &map,
+            map,
             path,
             code,
             Dialect::Bzl,
