@@ -22,6 +22,7 @@ use {
         policy::PythonPackagingPolicy, resource::PythonResource,
         resource_collection::PythonResourceAddCollectionContext,
     },
+    slog::info,
     starlark::{
         environment::TypeValues,
         eval::call_stack::CallStack,
@@ -36,7 +37,7 @@ use {
         },
     },
     starlark_dialect_build_targets::{optional_str_arg, optional_type_arg},
-    std::{convert::TryFrom, ops::Deref, sync::Arc},
+    std::{ops::Deref, sync::Arc},
 };
 
 /// A Starlark Value wrapper for `PythonDistribution` traits.
@@ -117,7 +118,7 @@ impl PythonDistributionValue {
         python_version: &Value,
     ) -> ValueResult {
         let build_target = optional_str_arg("build_target", build_target)?;
-        let python_version = optional_str_arg("python_version", &python_version)?;
+        let python_version = optional_str_arg("python_version", python_version)?;
 
         let pyoxidizer_context_value = get_context(type_values)?;
         let pyoxidizer_context = pyoxidizer_context_value
@@ -241,9 +242,9 @@ impl PythonDistributionValue {
         optional_type_arg(
             "packaging_policy",
             "PythonPackagingPolicy",
-            &packaging_policy,
+            packaging_policy,
         )?;
-        optional_type_arg("config", "PythonInterpreterConfig", &config)?;
+        optional_type_arg("config", "PythonInterpreterConfig", config)?;
 
         let dist = self.resolve_distribution(type_values, "resolve_distribution()")?;
 
@@ -294,37 +295,22 @@ impl PythonDistributionValue {
         {
             Some(dist.clone())
         } else {
-            let flavor = DistributionFlavor::Standalone;
-            let location = default_distribution_location(
-                &flavor,
-                &pyoxidizer_context.build_host_triple,
-                Some(dist.python_major_minor_version().as_str()),
-            )
-            .map_err(|e| {
-                ValueError::from(RuntimeError {
-                    code: "PYOXIDIZER_BUILD",
-                    message: format!("unable to find host Python distribution: {}", e),
-                    label: "to_python_executable()".to_string(),
-                })
-            })?;
+            let host_dist = pyoxidizer_context
+                .distribution_cache
+                .host_distribution(
+                    pyoxidizer_context.logger(),
+                    Some(dist.python_major_minor_version().as_str()),
+                    Some(&python_distributions_path),
+                )
+                .map_err(|e| {
+                    ValueError::from(RuntimeError {
+                        code: "PYOXIDIZER_BUILD",
+                        message: format!("{:?}", e),
+                        label: "to_python_executable()".to_string(),
+                    })
+                })?;
 
-            Some(
-                pyoxidizer_context
-                    .distribution_cache
-                    .resolve_distribution(
-                        pyoxidizer_context.logger(),
-                        &location,
-                        Some(&python_distributions_path),
-                    )
-                    .map_err(|e| {
-                        ValueError::from(RuntimeError {
-                            code: "PYOXIDIZER_BUILD",
-                            message: format!("unable to resolve host Python distribution: {}", e),
-                            label: "to_python_executable".to_string(),
-                        })
-                    })?
-                    .clone_trait(),
-            )
+            Some(host_dist.clone_trait())
         };
 
         let mut builder = dist
@@ -365,7 +351,7 @@ impl PythonDistributionValue {
                 // callbacks are automatically called.
 
                 let value =
-                    python_resource_to_value(LABEL, &type_values, &mut cs, resource, &policy)
+                    python_resource_to_value(LABEL, type_values, &mut cs, resource, &policy)
                         .map_err(|e| {
                             anyhow!("error converting PythonResource to Value: {:?}", e)
                         })?;
@@ -380,7 +366,7 @@ impl PythonDistributionValue {
             },
         );
 
-        builder
+        for action in builder
             .add_distribution_resources(Some(callback))
             .map_err(|e| {
                 ValueError::from(RuntimeError {
@@ -388,7 +374,10 @@ impl PythonDistributionValue {
                     message: format!("{:?}", e),
                     label: "to_python_executable()".to_string(),
                 })
-            })?;
+            })?
+        {
+            info!(pyoxidizer_context.logger(), "{}", action.to_string());
+        }
 
         Ok(Value::new(PythonExecutableValue::new(builder, policy)))
     }
@@ -430,17 +419,17 @@ starlark_module! { python_distribution_module =>
 
     PythonDistribution.make_python_packaging_policy(env env, this) {
         let mut this = this.downcast_mut::<PythonDistributionValue>().unwrap().unwrap();
-        this.make_python_packaging_policy_starlark(&env)
+        this.make_python_packaging_policy_starlark(env)
     }
 
     PythonDistribution.make_python_interpreter_config(env env, this) {
         let mut this = this.downcast_mut::<PythonDistributionValue>().unwrap().unwrap();
-        this.make_python_interpreter_config_starlark(&env)
+        this.make_python_interpreter_config_starlark(env)
     }
 
     PythonDistribution.python_resources(env env, call_stack cs, this) {
         let mut this = this.downcast_mut::<PythonDistributionValue>().unwrap().unwrap();
-        this.python_resources_starlark(&env, cs)
+        this.python_resources_starlark(env, cs)
     }
 
     PythonDistribution.to_python_executable(
@@ -453,7 +442,7 @@ starlark_module! { python_distribution_module =>
     ) {
         let mut this = this.downcast_mut::<PythonDistributionValue>().unwrap().unwrap();
         this.to_python_executable_starlark(
-            &env,
+            env,
             cs,
             name,
             &packaging_policy,
@@ -467,7 +456,7 @@ starlark_module! { python_distribution_module =>
         build_target=NoneType::None,
         python_version=NoneType::None
     ) {
-        PythonDistributionValue::default_python_distribution(&env, flavor, &build_target, &python_version)
+        PythonDistributionValue::default_python_distribution(env, flavor, &build_target, &python_version)
     }
 }
 
